@@ -8,12 +8,15 @@ use Mojo::Base 'Mojolicious::Plugin';
 
 use Text::Minify::XS ();
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 sub register {
     my ($self, $app, $conf) = @_;
     $app->hook( after_render => sub {
         my ($c, $output, $format) = @_;
+
+        return if $c->stash->{'mojox.no-minify'};
+
         if ($format eq "html") {
             $$output = Text::Minify::XS::minify( $$output );
         }
@@ -35,7 +38,7 @@ Mojolicious::Plugin::Text::Minify - remove HTML indentation on the fly
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -50,6 +53,9 @@ version v0.1.1
 This plugin uses L<Text::Minify::XS> to remove indentation and
 trailing whitespace from HTML content.
 
+If the C<mojox.no-minify> key in the stash is set to a true value,
+then the result will not be minified.
+
 Note that this is naive minifier which does not understand markup, so
 newlines will still be collapsed in HTML elements where whitespace is
 meaningful, e.g. C<pre> or C<textarea>.
